@@ -26,7 +26,7 @@ class CreateAvatarJob : public KJob
 {
      Q_OBJECT
     public:
-        explicit CreateAvatarJob(QObject* parent = 0);
+        explicit CreateAvatarJob(QObject* parent = nullptr);
 
         void start() Q_DECL_OVERRIDE;
         void setUrl(const QUrl &url);
